;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "embark" "20260520.28"
  "Conveniently act on minibuffer completions."
  '((emacs  "29.1")
    (compat "31"))
  :url "https://github.com/oantolin/embark"
  :commit "b3089f3f42a64e03666c44db089af8dfcfe51d98"
  :revdesc "b3089f3f42a6"
  :keywords '("convenience")
  :authors '(("Omar Antolín Camarena" . "omar@matem.unam.mx"))
  :maintainers '(("Omar Antolín Camarena" . "omar@matem.unam.mx")))
